@@ -61,11 +61,11 @@ foreach my $dir ($cfg->{cache_dir}, $cfg->{log_dir}) {
 check_install();
 
 # Remove these files/directories if they exist (obsolete)
-foreach my $rmdir ("$cfg->{cache_dir}/tmp", "$cfg->{cache_dir}/head") {
-	if (-d $rmdir) {
-		print "Doing 'rm -rf $rmdir' (obsolete)\n";
-		system("rm -rf $rmdir");
-	}
+foreach my $rmdir ("$cfg->{cache_dir}/tmp", "$cfg->{cache_dir}/temp", "$cfg->{cache_dir}/head") {
+    if (-d $rmdir) {
+	print "Doing 'rm -rf $rmdir' (obsolete)\n";
+	system("rm -rf $rmdir");
+    }
 }
 
 for ("README", "README.txt") {
