@@ -37,6 +37,7 @@ sub read_config {
 						   }
 						   $count},
 		  curl_idle_timeout => 120,
+		  curl_throttle => 10,
 		  daemon_port => 3142,
 		  debug => 0,
 		  denied_hosts => '',
@@ -74,6 +75,11 @@ sub read_config {
 							    Index(?:\.bz2)?
 							  )
 							) . ')$',
+		  skip_checksum_files_regexp => '^(?:' . join('|',
+							qw((?:In)?Release
+							   Release\.gpg
+							 )
+						       ) . ')$',
 		  index_files_regexp => '^(?:' . join('|',
 						      qw(Index(?:\.bz2)?
 							 Packages(?:\.gz|\.bz2)?
@@ -213,7 +219,7 @@ sub private_config {
 	. ')'/ge;
 
     # Precompile regexps so they will not be recompiled each time
-    $cfg->{$_} = qr/$cfg->{$_}/ foreach glob('{{checksum,index,installer,package,pdiff}_files,soap_url}_regexp');
+    $cfg->{$_} = qr/$cfg->{$_}/ foreach glob('{{{skip_,}checksum,index,installer,package,pdiff}_files,soap_url}_regexp');
 
 
     if ($cfg->{interface}) {
@@ -248,6 +254,9 @@ sub private_config {
 	    warn "Unrecognised $_: $cfg->{$_}. Ignoring.";
 	}
     }
+
+    # convert curl_throttle from milliseconds to seconds
+    $cfg->{_curl_throttle} = $cfg->{curl_throttle}/1000;
     return;
 }
 
